@@ -10,5 +10,9 @@ from .generator import (Generator, NullGenerator, ChildGenerator,
                         HTMLChildGenerator, JoinGenerator, HTMLJoinGenerator)
 from .image import Image
 from .inline import Span, Highlight, Strong, Alternate, Emphasis, Small
-from .list import OrderedList, UnorderedList, ListItem
-from .structure import Section, Navigation, Aside, Header, Footer, Heading
+from .link import Link
+from .list import (OrderedList, UnorderedList, ListItem, DescriptionList,
+                   DescriptionDefinition, DescriptionTerm)
+from .structure import (Section, Article, Navigation, Aside, Header, Footer,
+                        Heading)
+from .time import Time
